==> qtjambi-qt3drender-6.2.11-sources.jar: io/qt/qt3d/render/QNoDraw.java <==
package io.qt.qt3d.render;


/**
 * <p>When a Qt3DRender::QNoDraw node is present in a FrameGraph branch, this prevents the renderer from rendering any primitive</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qnodraw.html">Qt3DRender::QNoDraw</a></p>
 */
public class QNoDraw extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNoDraw.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QNoDraw(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNoDraw() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qnodraw.html#QNoDraw">Qt3DRender::QNoDraw::QNoDraw(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QNoDraw(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNoDraw instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNoDraw(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QNoDraw(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QNoDraw instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QNoDraw.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>When a Qt3DRender::QNoDraw node is present in a FrameGraph branch, this prevents the renderer from rendering any primitive</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qnodraw.html">Qt3DRender::QNoDraw</a></p>
 */
public class QNoDraw extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNoDraw.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QNoDraw(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNoDraw() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qnodraw.html#QNoDraw">Qt3DRender::QNoDraw::QNoDraw(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QNoDraw(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNoDraw instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNoDraw(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QNoDraw(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QNoDraw instance, QDeclarativeConstructor constructor);
    
}
